s/writeable/writable

"Writable" is the correct spelling according to Merriam-Webster:
https://www.merriam-webster.com/dictionary/writable

Change-Id: I36b48403275164bdc448f44e1e5e73f18b3be740
Reviewed-on: https://fuchsia-review.googlesource.com/c/shac-project/shac/+/904698
Commit-Queue: Auto-Submit <auto-submit@fuchsia-infra.iam.gserviceaccount.com>
Reviewed-by: Marc-Antoine Ruel <maruel@google.com>
Fuchsia-Auto-Submit: Oliver Newman <olivernewman@google.com>
diff --git a/internal/engine/runtime_ctx_os.go b/internal/engine/runtime_ctx_os.go
index aca6d78..e8af0fe 100644
--- a/internal/engine/runtime_ctx_os.go
+++ b/internal/engine/runtime_ctx_os.go
@@ -305,9 +305,9 @@
 	if runtime.GOOS != "windows" {
 		config.Mounts = []sandbox.Mount{
 			// TODO(olivernewman): Mount the checkout read-only unconditionally.
-			{Path: s.root, Writeable: s.writableRoot},
+			{Path: s.root, Writable: s.writableRoot},
 			// OS-provided utilities.
-			{Path: "/dev/null", Writeable: true},
+			{Path: "/dev/null", Writable: true},
 			{Path: "/dev/urandom"},
 			{Path: "/dev/zero"},
 			// DNS configs.
@@ -325,7 +325,7 @@
 			// Make the parent directory of tempDir available, since it is the root
 			// of all ctx.os.tempdir() calls, which can be used as scratch pads for
 			// this executable.
-			{Path: filepath.Dir(tempDir), Writeable: true},
+			{Path: filepath.Dir(tempDir), Writable: true},
 		}
 
 		// TODO(olivernewman): This is necessary because checks for shac itself
diff --git a/internal/sandbox/sandbox.go b/internal/sandbox/sandbox.go
index e0eec65..33a3a40 100644
--- a/internal/sandbox/sandbox.go
+++ b/internal/sandbox/sandbox.go
@@ -37,9 +37,9 @@
 	// Dest is the optional location to mount in the nsjail. If omitted, it will
 	// be assumed to be the same as Path.
 	Dest string
 	// Writeable controls whether the mount is writeable by processes within the
 	// nsjail.
-	Writeable bool
+	Writable bool
 }
 
 // Config represents the configuration for a sandboxed subprocess.
@@ -112,14 +112,14 @@
 		args = append(args, "--env", fmt.Sprintf("%s=%s", k, v))
 	}
 	// nsjail is strict about ordering of --bindmount flags. If /a and /a/b are
 	// both to be mounted (/a might be read-only while /a/b is writeable), then
 	// /a must precede /a/b in the arguments.
 	sort.Slice(config.Mounts, func(i, j int) bool {
 		return config.Mounts[i].Path < config.Mounts[j].Path
 	})
 	for _, mnt := range config.Mounts {
 		flag := "--bindmount_ro"
-		if mnt.Writeable {
+		if mnt.Writable {
 			flag = "--bindmount"
 		}
 		val := mnt.Path
@@ -37,9 +37,9 @@
 	// be assumed to be the same as Path.
 	Dest string
-	// Writeable controls whether the mount is writeable by processes within the
+	// Writable controls whether the mount is writable by processes within the
 	// nsjail.
@@ -112,14 +112,14 @@
 	}
 	// nsjail is strict about ordering of --bindmount flags. If /a and /a/b are
-	// both to be mounted (/a might be read-only while /a/b is writeable), then
+	// both to be mounted (/a might be read-only while /a/b is writable), then
 	// /a must precede /a/b in the arguments.
 	sort.Slice(config.Mounts, func(i, j int) bool {